IdentityEnrollmentConfig class

Constructors

IdentityEnrollmentConfig({IdentitySignatureType? signatureType, bool? enforceBiometric, bool? setInvalidatedByBiometricEnrollment, bool? useDeviceCredentials, bool? enableDecryption, String? promptSubtitle, String? promptDescription, String? cancelButtonText, bool? failIfExists})

Properties

cancelButtonText String?
getter/setter pair
enableDecryption bool?
getter/setter pair
enforceBiometric bool?
getter/setter pair
failIfExists bool?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
promptDescription String?
getter/setter pair
promptSubtitle String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setInvalidatedByBiometricEnrollment bool?
getter/setter pair
signatureType IdentitySignatureType?
getter/setter pair
useDeviceCredentials bool?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) IdentityEnrollmentConfig