IdentityError enum

Standardized error codes for the plugin.

Inheritance
Available extensions

Values

success → const IdentityError
userCanceled → const IdentityError
notAvailable → const IdentityError
notEnrolled → const IdentityError
lockedOut → const IdentityError
lockedOutPermanent → const IdentityError
keyNotFound → const IdentityError
keyInvalidated → const IdentityError
unknown → const IdentityError
invalidInput → const IdentityError
securityUpdateRequired → const IdentityError
notSupported → const IdentityError
systemCanceled → const IdentityError
promptError → const IdentityError
keyAlreadyExists → const IdentityError
passcodeNotSet → const IdentityError

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IdentityError>
A constant List of the values in this enum, in order of their declaration.