IdentitySignatureConfig class

Constructors

IdentitySignatureConfig({String? promptSubtitle, String? promptDescription, String? cancelButtonText, bool? allowDeviceCredentials})

Properties

allowDeviceCredentials bool?
getter/setter pair
cancelButtonText String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
promptDescription String?
getter/setter pair
promptSubtitle String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) IdentitySignatureConfig