LocalBiometricApi class

Constructors

LocalBiometricApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for LocalBiometricApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acknowledgeIdentityChange() Future<void>
checkAvailability() Future<IdentityAvailability>
decryptPayload(String payload, String? keyAlias, IdentityPayloadFormat payloadFormat, IdentityDecryptConfig? config, String? promptMessage) Future<IdentityDecryptResult>
enrollIdentity(String? keyAlias, IdentityEnrollmentConfig? config, IdentityKeyFormat keyFormat, String? promptMessage) Future<IdentityEnrollmentResult>
getIdentityStatus(String? keyAlias, bool checkValidity, IdentityKeyFormat keyFormat) Future<IdentityInfo>
isDeviceSecure() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revokeAllIdentities() Future<bool>
revokeIdentity(String? keyAlias) Future<bool>
signPayload(String payload, String? keyAlias, IdentitySignatureConfig? config, IdentitySignatureFormat signatureFormat, IdentityKeyFormat keyFormat, String? promptMessage) Future<IdentitySignatureResult>
signPayloadBytes(Uint8List payload, String? keyAlias, IdentitySignatureConfig? config, IdentitySignatureFormat signatureFormat, IdentityKeyFormat keyFormat, String? promptMessage) Future<IdentitySignatureResult>
toString() String
A string representation of this object.
inherited
verifyPresence(String promptMessage, PresencePromptConfig? config) Future<PresencePromptResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>