getIdentityStatus method
Future<IdentityInfo>
getIdentityStatus({
- String? keyAlias,
- bool checkValidity = false,
- IdentityKeyFormat keyFormat = IdentityKeyFormat.base64,
Returns the current status and metadata of an enrolled identity.
If checkValidity is true, it performs a hardware check to ensure the key is still valid.
Implementation
Future<IdentityInfo> getIdentityStatus({
String? keyAlias,
bool checkValidity = false,
IdentityKeyFormat keyFormat = IdentityKeyFormat.base64,
}) => _api.getIdentityStatus(keyAlias, checkValidity, keyFormat);